@@ -42,13 +42,12 @@ impl ControlFlowGraph {
             .iter()
             .filter_map(|x| match &self.graph[*x] {
                 ControlFlowGraphNode::EnumVariant {
-                    span,
                     variant_name,
                     is_public,
                 } if !is_public => Some(CompileWarning {
-                    span: span.clone(),
+                    span: variant_name.span().clone(),
                     warning_content: Warning::DeadEnumVariant {
-                        variant_name: variant_name.to_string(),
+                        variant_name: variant_name.clone(),
                     },
                 }),
                 _ => None,
@@ -62,13 +61,12 @@ impl ControlFlowGraph {
                     construct_dead_code_warning_from_node(node)
                 }
                 ControlFlowGraphNode::EnumVariant {
-                    span,
                     variant_name,
                     is_public,
                 } if !is_public => Some(CompileWarning {
-                    span: span.clone(),
+                    span: variant_name.span().clone(),
                     warning_content: Warning::DeadEnumVariant {
-                        variant_name: variant_name.to_string(),
+                        variant_name: variant_name.clone(),
                     },
                 }),
                 ControlFlowGraphNode::EnumVariant { .. } => None,
