@@ -113,6 +113,10 @@ impl CallPath {
         )
     }
 
+    pub(crate) fn full_path(&self) -> impl Iterator<Item = &Ident> {
+        self.prefixes.iter().chain(Some(&self.suffix))
+    }
+
     pub(crate) fn friendly_name(&self) -> String {
         let mut buf = String::new();
         for prefix in self.prefixes.iter() {
