@@ -7,15 +7,14 @@ use crate::{
             TypedExpressionVariant, TypedReturnStatement, TypedVariableDeclaration,
             VariableMutability,
         },
-        create_new_scope, NamespaceWrapper, TypeCheckArguments, TypedAstNode, TypedAstNodeContent,
+        TypeCheckArguments, TypedAstNode, TypedAstNodeContent,
     },
     type_engine::*,
     Ident, TypeParameter,
 };
-
-use sway_types::{Function, Property, Span};
-
+use fuels_types::{Function, Property};
 use sha2::{Digest, Sha256};
+use sway_types::Span;
 
 mod function_parameter;
 pub use function_parameter::*;
@@ -74,7 +73,6 @@ impl TypedFunctionDeclaration {
         let TypeCheckArguments {
             checkee: fn_decl,
             namespace,
-            crate_namespace,
             self_type,
             build_config,
             dead_code_graph,
@@ -100,12 +98,13 @@ impl TypedFunctionDeclaration {
         let type_mapping = insert_type_parameters(&type_parameters);
 
         // insert parameters and generic type declarations into namespace
-        let namespace = create_new_scope(namespace);
+        let mut fn_namespace = namespace.clone();
 
         // check to see if the type parameters shadow one another
         for type_parameter in type_parameters.iter() {
             check!(
-                namespace.insert(type_parameter.name_ident.clone(), type_parameter.into()),
+                fn_namespace
+                    .insert_symbol(type_parameter.name_ident.clone(), type_parameter.into()),
                 continue,
                 warnings,
                 errors
@@ -117,7 +116,7 @@ impl TypedFunctionDeclaration {
                 match look_up_type_id(parameter.type_id).matches_type_parameter(&type_mapping) {
                     Some(matching_id) => insert_type(TypeInfo::Ref(matching_id)),
                     None => check!(
-                        namespace.resolve_type_with_self(
+                        fn_namespace.resolve_type_with_self(
                             look_up_type_id(parameter.type_id),
                             self_type,
                             parameter.type_span.clone(),
@@ -131,7 +130,7 @@ impl TypedFunctionDeclaration {
         });
 
         for FunctionParameter { name, type_id, .. } in parameters.clone() {
-            namespace.insert(
+            fn_namespace.insert_symbol(
                 name.clone(),
                 TypedDeclaration::VariableDeclaration(TypedVariableDeclaration {
                     name: name.clone(),
@@ -151,7 +150,7 @@ impl TypedFunctionDeclaration {
         let return_type = match return_type.matches_type_parameter(&type_mapping) {
             Some(matching_id) => insert_type(TypeInfo::Ref(matching_id)),
             None => check!(
-                namespace.resolve_type_with_self(
+                fn_namespace.resolve_type_with_self(
                     return_type,
                     self_type,
                     return_type_span.clone(),
@@ -168,8 +167,7 @@ impl TypedFunctionDeclaration {
         let (mut body, _implicit_block_return) = check!(
             TypedCodeBlock::type_check(TypeCheckArguments {
                 checkee: body.clone(),
-                namespace,
-                crate_namespace,
+                namespace: &mut fn_namespace,
                 return_type_annotation: return_type,
                 help_text:
                     "Function body's return type does not match up with its return type annotation.",
