@@ -213,7 +213,6 @@ impl TypedAstNode {
         let TypeCheckArguments {
             checkee: node,
             namespace,
-            crate_namespace,
             return_type_annotation,
             help_text,
             self_type,
@@ -224,53 +223,52 @@ impl TypedAstNode {
         } = arguments;
         let mut warnings = Vec::new();
         let mut errors = Vec::new();
+
         // A little utility used to check an ascribed type matches its associated expression.
-        let mut type_check_ascribed_expr = |namespace: crate::semantic_analysis::NamespaceRef,
-                                            crate_namespace: NamespaceRef,
-                                            type_ascription: TypeInfo,
-                                            value| {
-            let type_id = check!(
-                namespace.resolve_type_with_self(
-                    type_ascription,
-                    self_type,
-                    node.span.clone(),
-                    false
-                ),
-                insert_type(TypeInfo::ErrorRecovery),
-                warnings,
-                errors,
-            );
-            TypedExpression::type_check(TypeCheckArguments {
-                checkee: value,
-                namespace,
-                crate_namespace,
-                return_type_annotation: type_id,
-                help_text: "This declaration's type annotation  does \
+        let mut type_check_ascribed_expr =
+            |namespace: &mut Namespace, type_ascription: TypeInfo, value| {
+                let type_id = check!(
+                    namespace.resolve_type_with_self(
+                        type_ascription,
+                        self_type,
+                        node.span.clone(),
+                        false
+                    ),
+                    insert_type(TypeInfo::ErrorRecovery),
+                    warnings,
+                    errors,
+                );
+                TypedExpression::type_check(TypeCheckArguments {
+                    checkee: value,
+                    namespace,
+                    return_type_annotation: type_id,
+                    help_text: "This declaration's type annotation  does \
                      not match up with the assigned expression's type.",
-                self_type,
-                build_config,
-                dead_code_graph,
-                mode: Mode::NonAbi,
-                opts,
-            })
-        };
+                    self_type,
+                    build_config,
+                    dead_code_graph,
+                    mode: Mode::NonAbi,
+                    opts,
+                })
+            };
 
         let node = TypedAstNode {
             content: match node.content.clone() {
                 AstNodeContent::UseStatement(a) => {
-                    let from_module = if a.is_absolute {
-                        Some(crate_namespace)
+                    let path = if a.is_absolute {
+                        a.call_path.clone()
                     } else {
-                        None
+                        namespace
+                            .mod_path()
+                            .iter()
+                            .chain(&a.call_path)
+                            .cloned()
+                            .collect()
                     };
                     let mut res = match a.import_type {
-                        ImportType::Star => namespace.star_import(from_module, a.call_path),
-                        ImportType::SelfImport => {
-                            namespace.self_import(from_module, a.call_path, a.alias)
-                        }
-                        ImportType::Item(s) => {
-                            namespace.item_import(from_module, a.call_path, &s, a.alias)
-                        }
+                        ImportType::Star => namespace.star_import(&path),
+                        ImportType::SelfImport => namespace.self_import(&path, a.alias),
+                        ImportType::Item(s) => namespace.item_import(&path, &s, a.alias),
                     };
                     warnings.append(&mut res.warnings);
                     errors.append(&mut res.errors);
@@ -322,7 +320,6 @@ impl TypedAstNode {
                                 TypedExpression::type_check(TypeCheckArguments {
                                     checkee: body,
                                     namespace,
-                                    crate_namespace,
                                     return_type_annotation: type_ascription,
                                     help_text: "Variable declaration's type annotation does \
                      not match up with the assigned expression's type.",
@@ -347,7 +344,7 @@ impl TypedAstNode {
                                     const_decl_origin: false,
                                     type_ascription,
                                 });
-                            namespace.insert(name, typed_var_decl.clone());
+                            namespace.insert_symbol(name, typed_var_decl.clone());
                             typed_var_decl
                         }
                         Declaration::ConstantDeclaration(ConstantDeclaration {
@@ -356,12 +353,8 @@ impl TypedAstNode {
                             value,
                             visibility,
                         }) => {
-                            let result = type_check_ascribed_expr(
-                                namespace,
-                                crate_namespace,
-                                type_ascription.clone(),
-                                value,
-                            );
+                            let result =
+                                type_check_ascribed_expr(namespace, type_ascription.clone(), value);
                             let value = check!(
                                 result,
                                 error_recovery_expr(name.span().clone()),
@@ -380,7 +373,7 @@ impl TypedAstNode {
                                     const_decl_origin: true,
                                     type_ascription: insert_type(type_ascription),
                                 });
-                            namespace.insert(name, typed_const_decl.clone());
+                            namespace.insert_symbol(name, typed_const_decl.clone());
                             typed_const_decl
                         }
                         Declaration::EnumDeclaration(e) => {
@@ -389,7 +382,7 @@ impl TypedAstNode {
                             );
 
                             let _ = check!(
-                                namespace.insert(e.name, decl.clone()),
+                                namespace.insert_symbol(e.name, decl.clone()),
                                 return err(warnings, errors),
                                 warnings,
                                 errors
@@ -401,7 +394,6 @@ impl TypedAstNode {
                                 TypedFunctionDeclaration::type_check(TypeCheckArguments {
                                     checkee: fn_decl.clone(),
                                     namespace,
-                                    crate_namespace,
                                     return_type_annotation: insert_type(TypeInfo::Unknown),
                                     help_text,
                                     self_type,
@@ -414,7 +406,7 @@ impl TypedAstNode {
                                 warnings,
                                 errors
                             );
-                            namespace.insert(
+                            namespace.insert_symbol(
                                 decl.name.clone(),
                                 TypedDeclaration::FunctionDeclaration(decl.clone()),
                             );
@@ -425,7 +417,6 @@ impl TypedAstNode {
                                 type_check_trait_decl(TypeCheckArguments {
                                     checkee: trait_decl,
                                     namespace,
-                                    crate_namespace,
                                     self_type,
                                     build_config,
                                     dead_code_graph,
@@ -446,7 +437,6 @@ impl TypedAstNode {
                                     TypeCheckArguments {
                                         checkee: (lhs, rhs),
                                         namespace,
-                                        crate_namespace,
                                         self_type,
                                         build_config,
                                         dead_code_graph,
@@ -467,7 +457,6 @@ impl TypedAstNode {
                             implementation_of_trait(
                                 impl_trait,
                                 namespace,
-                                crate_namespace,
                                 build_config,
                                 dead_code_graph,
                                 opts,
@@ -493,13 +482,15 @@ impl TypedAstNode {
                                     break;
                                 }
                             }
-                            let impl_namespace = create_new_scope(namespace);
+
+                            let mut impl_namespace = namespace.clone();
                             for type_parameter in type_parameters.iter() {
-                                impl_namespace.insert(
+                                impl_namespace.insert_symbol(
                                     type_parameter.name_ident.clone(),
                                     type_parameter.into(),
                                 );
                             }
+
                             // Resolve the Self type as it's most likely still 'Custom' and use the
                             // resolved type for self instead.
                             let implementing_for_type_id = check!(
@@ -531,8 +522,7 @@ impl TypedAstNode {
                                 }
                                 let args = TypeCheckArguments {
                                     checkee: fn_decl,
-                                    namespace: impl_namespace,
-                                    crate_namespace,
+                                    namespace: &mut impl_namespace,
                                     return_type_annotation: insert_type(TypeInfo::Unknown),
                                     help_text: "",
                                     self_type: implementing_for_type_id,
@@ -606,7 +596,7 @@ impl TypedAstNode {
 
                             // insert struct into namespace
                             let _ = check!(
-                                namespace.insert(
+                                namespace.insert_symbol(
                                     decl.name.clone(),
                                     TypedDeclaration::StructDeclaration(decl.clone()),
                                 ),
@@ -640,7 +630,6 @@ impl TypedAstNode {
                                 type_check_trait_methods(
                                     methods.clone(),
                                     namespace,
-                                    crate_namespace,
                                     self_type,
                                     build_config,
                                     dead_code_graph,
@@ -656,7 +645,7 @@ impl TypedAstNode {
                                 name: name.clone(),
                                 span,
                             });
-                            namespace.insert(name, decl.clone());
+                            namespace.insert_symbol(name, decl.clone());
                             decl
                         }
                         Declaration::StorageDeclaration(StorageDeclaration { span, fields }) => {
@@ -691,7 +680,6 @@ impl TypedAstNode {
                         TypedExpression::type_check(TypeCheckArguments {
                             checkee: a.clone(),
                             namespace,
-                            crate_namespace,
                             return_type_annotation: insert_type(TypeInfo::Unknown),
                             help_text: Default::default(),
                             self_type,
@@ -712,7 +700,6 @@ impl TypedAstNode {
                             TypedExpression::type_check(TypeCheckArguments {
                                 checkee: expr.clone(),
                                 namespace,
-                                crate_namespace,
                                 // we use "unknown" here because return statements do not
                                 // necessarily follow the type annotation of their immediate
                                 // surrounding context. Because a return statement is control flow
@@ -742,7 +729,6 @@ impl TypedAstNode {
                         TypedExpression::type_check(TypeCheckArguments {
                             checkee: expr.clone(),
                             namespace,
-                            crate_namespace,
                             return_type_annotation,
                             help_text: "Implicit return must match up with block's type.",
                             self_type,
@@ -762,7 +748,6 @@ impl TypedAstNode {
                         TypedExpression::type_check(TypeCheckArguments {
                             checkee: condition,
                             namespace,
-                            crate_namespace,
                             return_type_annotation: insert_type(TypeInfo::Boolean),
                             help_text:
                                 "A while loop's loop condition must be a boolean expression.",
@@ -780,7 +765,6 @@ impl TypedAstNode {
                         TypedCodeBlock::type_check(TypeCheckArguments {
                             checkee: body.clone(),
                             namespace,
-                            crate_namespace,
                             return_type_annotation: insert_type(TypeInfo::Tuple(Vec::new())),
                             help_text:
                                 "A while loop's loop body cannot implicitly return a value.Try \
@@ -835,71 +819,50 @@ impl TypedAstNode {
 /// and appends the module's content to the control flow graph for later analysis.
 fn import_new_file(
     statement: &IncludeStatement,
-    namespace: NamespaceRef,
+    namespace: &mut Namespace,
     build_config: &BuildConfig,
     dead_code_graph: &mut ControlFlowGraph,
 ) -> CompileResult<()> {
-    let mut warnings = vec![];
-    let mut errors = vec![];
+    let canonical_path = build_config
+        .dir_of_code
+        .iter()
+        .chain(statement.path_span.as_str().split('/').map(AsRef::as_ref))
+        .collect::<std::path::PathBuf>()
+        .with_extension(crate::constants::DEFAULT_FILE_EXTENSION);
 
-    let mut canonical_path = (*build_config.dir_of_code).clone();
-    canonical_path.push(statement.path_span.as_str());
-    canonical_path.set_extension(crate::constants::DEFAULT_FILE_EXTENSION);
-
-    let file_name = match canonical_path.strip_prefix(build_config.manifest_path.parent().unwrap())
-    {
+    let manifest_dir = build_config.manifest_path.parent().unwrap();
+    let file_name = match canonical_path.strip_prefix(manifest_dir) {
         Ok(file_name) => Arc::new(file_name.to_path_buf()),
-        Err(_) => return err(warnings, errors),
+        Err(_) => return err(vec![], vec![]),
     };
 
-    let res = if canonical_path.exists() {
-        std::fs::read_to_string(&*canonical_path)
-    } else {
-        errors.push(CompileError::FileNotFound {
-            span: statement.path_span.clone(),
+    if !canonical_path.exists() {
+        let err = CompileError::FileNotFound {
             file_path: canonical_path.to_string_lossy().to_string(),
-        });
-        return ok((), warnings, errors);
-    };
+            span: statement.path_span.clone(),
+        };
+        return ok((), vec![], vec![err]);
+    }
 
-    let file_as_string = match res {
+    let file_str: Arc<str> = match std::fs::read_to_string(&canonical_path) {
         Ok(s) => Arc::from(s),
         Err(e) => {
-            errors.push(CompileError::FileCouldNotBeRead {
+            let err = CompileError::FileCouldNotBeRead {
                 span: statement.path_span.clone(),
                 file_path: canonical_path.to_string_lossy().to_string(),
                 stringified_error: e.to_string(),
-            });
-            return ok((), warnings, errors);
+            };
+            return ok((), vec![], vec![err]);
         }
     };
 
     let mut dep_config = build_config.clone();
-    let dep_path = {
-        canonical_path.pop();
-        canonical_path
-    };
+    let dep_path = canonical_path.parent().unwrap();
     dep_config.file_name = file_name;
-    dep_config.dir_of_code = Arc::new(dep_path);
-    let dep_namespace = create_new_scope(namespace);
-    let crate::InnerDependencyCompileResult {
-        name,
-        namespace: module,
-        ..
-    } = check!(
-        crate::compile_inner_dependency(file_as_string, dep_namespace, dep_config, dead_code_graph),
-        return err(warnings, errors),
-        warnings,
-        errors
-    );
+    dep_config.dir_of_code = Arc::new(dep_path.to_owned());
 
-    let name = match statement.alias {
-        Some(ref alias) => alias,
-        None => &name,
-    };
-    let name = name.as_str().to_string();
-    namespace.insert_module(name, module);
-    ok((), warnings, errors)
+    let alias = statement.alias.as_ref();
+    crate::compile_inner_dependency(file_str, alias, dep_config, namespace, dead_code_graph)
 }
 
 fn reassignment(
@@ -909,7 +872,6 @@ fn reassignment(
     let TypeCheckArguments {
         checkee: (lhs, rhs),
         namespace,
-        crate_namespace,
         self_type,
         build_config,
         dead_code_graph,
@@ -924,7 +886,7 @@ fn reassignment(
             match *var {
                 Expression::VariableExpression { name, span } => {
                     // check that the reassigned name exists
-                    let thing_to_reassign = match namespace.clone().get_symbol(&name).value {
+                    let thing_to_reassign = match namespace.resolve_symbol(&name).cloned().value {
                         Some(TypedDeclaration::VariableDeclaration(TypedVariableDeclaration {
                             body,
                             is_mutable,
@@ -932,10 +894,7 @@ fn reassignment(
                             ..
                         })) => {
                             if !is_mutable.is_mutable() {
-                                errors.push(CompileError::AssignmentToNonMutable(
-                                    name.as_str().to_string(),
-                                    span.clone(),
-                                ));
+                                errors.push(CompileError::AssignmentToNonMutable { name });
                             }
 
                             body
@@ -950,8 +909,7 @@ fn reassignment(
                         }
                         None => {
                             errors.push(CompileError::UnknownVariable {
-                                var_name: name.as_str().to_string(),
-                                span: name.span().clone(),
+                                var_name: name.clone(),
                             });
                             return err(warnings, errors);
                         }
@@ -963,7 +921,6 @@ fn reassignment(
                         TypedExpression::type_check(TypeCheckArguments {
                             checkee: rhs,
                             namespace,
-                            crate_namespace,
                             return_type_annotation: rhs_type_id,
                             help_text:
                                 "You can only reassign a value of the same type to a variable.",
@@ -1002,7 +959,6 @@ fn reassignment(
                             TypedExpression::type_check(TypeCheckArguments {
                                 checkee: expr.clone(),
                                 namespace,
-                                crate_namespace,
                                 return_type_annotation: insert_type(TypeInfo::Unknown),
                                 help_text: Default::default(),
                                 self_type,
@@ -1065,7 +1021,6 @@ fn reassignment(
                         TypedExpression::type_check(TypeCheckArguments {
                             checkee: rhs,
                             namespace,
-                            crate_namespace,
                             return_type_annotation: ty_of_field,
                             help_text: Default::default(),
                             self_type,
@@ -1097,7 +1052,6 @@ fn reassignment(
         ReassignmentTarget::StorageField(fields) => reassign_storage_subfield(TypeCheckArguments {
             checkee: (fields, span, rhs),
             namespace,
-            crate_namespace,
             return_type_annotation: insert_type(TypeInfo::Unknown),
             help_text: Default::default(),
             self_type,
@@ -1114,16 +1068,16 @@ fn reassignment(
 /// which is meant to be the namespace of the subtrait in question
 fn handle_supertraits(
     supertraits: &[Supertrait],
-    trait_namespace: NamespaceRef,
-    namespace: NamespaceRef,
+    trait_namespace: &mut Namespace,
 ) -> CompileResult<()> {
     let mut warnings = Vec::new();
     let mut errors = Vec::new();
 
     for supertrait in supertraits.iter() {
-        match namespace
-            .get_call_path(&supertrait.name)
+        match trait_namespace
+            .resolve_call_path(&supertrait.name)
             .ok(&mut warnings, &mut errors)
+            .cloned()
         {
             Some(TypedDeclaration::TraitDeclaration(TypedTraitDeclaration {
                 ref interface_surface,
@@ -1142,21 +1096,22 @@ fn handle_supertraits(
                 );
 
                 // insert dummy versions of the methods of all of the supertraits
+                let dummy_funcs = check!(
+                    convert_trait_methods_to_dummy_funcs(methods, trait_namespace),
+                    return err(warnings, errors),
+                    warnings,
+                    errors
+                );
                 trait_namespace.insert_trait_implementation(
                     supertrait.name.clone(),
                     TypeInfo::SelfType,
-                    check!(
-                        convert_trait_methods_to_dummy_funcs(methods, namespace),
-                        return err(warnings, errors),
-                        warnings,
-                        errors
-                    ),
+                    dummy_funcs,
                 );
 
                 // Recurse to insert dummy versions of interfaces and methods of the *super*
                 // supertraits
                 check!(
-                    handle_supertraits(supertraits, trait_namespace, namespace),
+                    handle_supertraits(supertraits, trait_namespace),
                     return err(warnings, errors),
                     warnings,
                     errors
@@ -1168,8 +1123,7 @@ fn handle_supertraits(
                 })
             }
             _ => errors.push(CompileError::TraitNotFound {
-                name: supertrait.name.span().as_str().to_string(),
-                span: supertrait.name.span().clone(),
+                name: supertrait.name.clone(),
             }),
         }
     }
@@ -1183,7 +1137,6 @@ fn type_check_trait_decl(
     let TypeCheckArguments {
         checkee: trait_decl,
         namespace,
-        crate_namespace,
         return_type_annotation: _return_type_annotation,
         help_text: _help_text,
         build_config,
@@ -1202,11 +1155,12 @@ fn type_check_trait_decl(
         errors
     );
 
-    let trait_namespace = create_new_scope(namespace);
+    // A temporary namespace for checking within the trait's scope.
+    let mut trait_namespace = namespace.clone();
 
     // Recursively handle supertraits: make their interfaces and methods available to this trait
     check!(
-        handle_supertraits(&trait_decl.supertraits, trait_namespace, namespace),
+        handle_supertraits(&trait_decl.supertraits, &mut trait_namespace),
         return err(warnings, errors),
         warnings,
         errors
@@ -1230,8 +1184,7 @@ fn type_check_trait_decl(
     let _methods = check!(
         type_check_trait_methods(
             trait_decl.methods.clone(),
-            trait_namespace,
-            crate_namespace,
+            &mut trait_namespace,
             insert_type(TypeInfo::SelfType),
             build_config,
             dead_code_graph,
@@ -1247,13 +1200,13 @@ fn type_check_trait_decl(
         supertraits: trait_decl.supertraits.to_vec(),
         visibility: trait_decl.visibility,
     });
-    namespace.insert(trait_decl.name, typed_trait_decl.clone());
+    namespace.insert_symbol(trait_decl.name, typed_trait_decl.clone());
     ok(typed_trait_decl, warnings, errors)
 }
 
 fn type_check_interface_surface(
     interface_surface: Vec<TraitFn>,
-    namespace: crate::semantic_analysis::NamespaceRef,
+    namespace: &mut Namespace,
 ) -> CompileResult<Vec<TypedTraitFn>> {
     let mut warnings = vec![];
     let mut errors = vec![];
@@ -1311,8 +1264,7 @@ fn type_check_interface_surface(
 
 fn type_check_trait_methods(
     methods: Vec<FunctionDeclaration>,
-    namespace: crate::semantic_analysis::NamespaceRef,
-    crate_namespace: NamespaceRef,
+    namespace: &mut Namespace,
     self_type: TypeId,
     build_config: &BuildConfig,
     dead_code_graph: &mut ControlFlowGraph,
@@ -1332,7 +1284,6 @@ fn type_check_trait_methods(
         ..
     } in methods
     {
-        let function_namespace = namespace;
         parameters.clone().into_iter().for_each(
             |FunctionParameter {
                  name,
@@ -1340,7 +1291,7 @@ fn type_check_trait_methods(
                  ..
              }| {
                 let r#type = check!(
-                    function_namespace.resolve_type_with_self(
+                    namespace.resolve_type_with_self(
                         look_up_type_id(*r#type),
                         crate::type_engine::insert_type(TypeInfo::SelfType),
                         name.span().clone(),
@@ -1350,7 +1301,7 @@ fn type_check_trait_methods(
                     warnings,
                     errors,
                 );
-                function_namespace.insert(
+                namespace.insert_symbol(
                     name.clone(),
                     TypedDeclaration::VariableDeclaration(TypedVariableDeclaration {
                         name: name.clone(),
@@ -1398,7 +1349,7 @@ fn type_check_trait_methods(
                     }
                 }) {
                     errors.push(CompileError::TypeParameterNotInTypeScope {
-                        name: name.to_string(),
+                        name: name.clone(),
                         span: span.clone(),
                         comma_separated_generic_params: comma_separated_generic_params.clone(),
                         fn_name: fn_name.clone(),
@@ -1418,7 +1369,7 @@ fn type_check_trait_methods(
                     TypedFunctionParameter {
                         name,
                         r#type: check!(
-                            function_namespace.resolve_type_with_self(
+                            namespace.resolve_type_with_self(
                                 look_up_type_id(type_id),
                                 crate::type_engine::insert_type(TypeInfo::SelfType),
                                 type_span.clone(),
@@ -1436,7 +1387,7 @@ fn type_check_trait_methods(
 
         // TODO check code block implicit return
         let return_type = check!(
-            function_namespace.resolve_type_with_self(
+            namespace.resolve_type_with_self(
                 return_type,
                 self_type,
                 return_type_span.clone(),
@@ -1449,8 +1400,7 @@ fn type_check_trait_methods(
         let (body, _code_block_implicit_return) = check!(
             TypedCodeBlock::type_check(TypeCheckArguments {
                 checkee: body,
-                namespace: function_namespace,
-                crate_namespace,
+                namespace,
                 return_type_annotation: return_type,
                 help_text: "Trait method body's return type does not match up with \
                                          its return type annotation.",
@@ -1487,7 +1437,7 @@ fn type_check_trait_methods(
 /// the parameters and the return types are type checked.
 fn convert_trait_methods_to_dummy_funcs(
     methods: &[FunctionDeclaration],
-    namespace: crate::semantic_analysis::NamespaceRef,
+    trait_namespace: &mut Namespace,
 ) -> CompileResult<Vec<TypedFunctionDeclaration>> {
     let mut warnings = vec![];
     let mut errors = vec![];
@@ -1517,7 +1467,7 @@ fn convert_trait_methods_to_dummy_funcs(
                          }| TypedFunctionParameter {
                             name: name.clone(),
                             r#type: check!(
-                                namespace.resolve_type_with_self(
+                                trait_namespace.resolve_type_with_self(
                                     look_up_type_id(*type_id),
                                     crate::type_engine::insert_type(TypeInfo::SelfType),
                                     type_span.clone(),
@@ -1533,7 +1483,7 @@ fn convert_trait_methods_to_dummy_funcs(
                     .collect(),
                 span: name.span().clone(),
                 return_type: check!(
-                    namespace.resolve_type_with_self(
+                    trait_namespace.resolve_type_with_self(
                         return_type.clone(),
                         crate::type_engine::insert_type(TypeInfo::SelfType),
                         return_type_span.clone(),
@@ -1630,7 +1580,6 @@ fn reassign_storage_subfield(
     let TypeCheckArguments {
         checkee: (fields, span, rhs),
         namespace,
-        crate_namespace,
         return_type_annotation: _return_type_annotation,
         help_text: _help_text,
         self_type,
@@ -1665,8 +1614,7 @@ fn reassign_storage_subfield(
         Some((ix, TypedStorageField { r#type, .. })) => (StateIndex::new(ix), r#type),
         None => {
             errors.push(CompileError::StorageFieldDoesNotExist {
-                name: first_field.as_str().to_string(),
-                span: first_field.span().clone(),
+                name: first_field.clone(),
             });
             return err(warnings, errors);
         }
@@ -1714,8 +1662,7 @@ fn reassign_storage_subfield(
                 errors.push(CompileError::FieldNotFound {
                     field_name: field.clone(),
                     available_fields: available_fields.join(", "),
-                    struct_name: type_checked_buf.last().unwrap().name.as_str().to_string(),
-                    span: field.span().clone(),
+                    struct_name: type_checked_buf.last().unwrap().name.clone(),
                 });
                 return err(warnings, errors);
             }
@@ -1725,7 +1672,6 @@ fn reassign_storage_subfield(
         TypedExpression::type_check(TypeCheckArguments {
             checkee: rhs,
             namespace,
-            crate_namespace,
             return_type_annotation: curr_type,
             help_text: Default::default(),
             self_type,
