@@ -6,8 +6,7 @@ use crate::type_engine::*;
 
 pub struct TypeCheckArguments<'a, T> {
     pub checkee: T,
-    pub namespace: NamespaceRef,
-    pub crate_namespace: NamespaceRef,
+    pub namespace: &'a mut Namespace,
     pub return_type_annotation: TypeId,
     pub help_text: &'static str,
     pub self_type: TypeId,
