@@ -273,10 +273,10 @@ impl TypeInfo {
         let mut errors = vec![];
         let mut iter = type_name_pair.into_inner();
         let input = iter.next().unwrap();
-        let span = Span {
-            span: input.as_span(),
-            path: config.map(|config| config.dir_of_code.clone()),
-        };
+        let span = Span::from_pest(
+            input.as_span(),
+            config.map(|config| config.dir_of_code.clone()),
+        );
         let type_info = match input.as_rule() {
             Rule::str_type => {
                 let type_info = check!(
@@ -422,10 +422,10 @@ impl TypeInfo {
                 errors
             ),
             _ => {
-                let span = Span {
-                    span: input.as_span(),
-                    path: config.map(|config| config.dir_of_code.clone()),
-                };
+                let span = Span::from_pest(
+                    input.as_span(),
+                    config.map(|config| config.dir_of_code.clone()),
+                );
                 errors.push(CompileError::Internal(
                     "Unexpected token while parsing type.",
                     span,
@@ -442,10 +442,10 @@ impl TypeInfo {
     ) -> CompileResult<Self> {
         let warnings = vec![];
         let errors = vec![];
-        let span = Span {
-            span: input.as_span(),
-            path: config.map(|config| config.dir_of_code.clone()),
-        };
+        let span = Span::from_pest(
+            input.as_span(),
+            config.map(|config| config.dir_of_code.clone()),
+        );
         ok(
             match input.as_str().trim() {
                 "u8" => TypeInfo::UnsignedInteger(IntegerBits::Eight),
