@@ -4,10 +4,10 @@ use clap::Parser as ClapParser;
 use pest::Parser;
 use std::sync::Arc;
 use sway_core::{
-    create_module,
     parse_tree::declaration::FunctionDeclaration,
     semantic_analysis::{
         ast_node::{declaration::TypedFunctionDeclaration, impl_trait::Mode},
+        namespace::{self, Namespace},
         TypeCheckArguments,
     },
     type_engine::*,
@@ -35,11 +35,10 @@ fn main() {
         FunctionDeclaration::parse_from_pair(parsed_fn_decl.next().unwrap(), Default::default())
             .unwrap(&mut warnings, &mut errors);
 
-    let namespace = create_module();
+    let mut namespace = Namespace::init_root(namespace::Module::default());
     let res = TypedFunctionDeclaration::type_check(TypeCheckArguments {
         checkee: parsed_fn_decl,
-        namespace,
-        crate_namespace: namespace,
+        namespace: &mut namespace,
         help_text: Default::default(),
         return_type_annotation: insert_type(TypeInfo::Unknown),
         self_type: insert_type(TypeInfo::Unknown),
